@@ -152,8 +152,7 @@ class Release:
             sys.exit(0)
 
         self._start_deploy(version, countries)
-        commits = self._github.get_commits_since_release(self._repo, version)
-        self._manage_youtrack_card(commits, version, countries)
+        self._manage_youtrack_card(version, countries)
 
     def _rollback(self):
         countries = prompt_utils.ask_multiple_choices(
@@ -240,10 +239,12 @@ class Release:
             rel for rel in releases if semver.compare(threshold, rel.tag_name) == 1
         ][0:4]
 
-    def _manage_youtrack_card(self, commits, new_version, countries):
+    def _manage_youtrack_card(self, version, countries):
         release_state = self._config.youtrack["release_state"]
 
-        issue_ids = self._youtrack.get_issue_ids(commits)
+        release_body = self._repo.get_release(version).body
+
+        issue_ids = self._youtrack.get_ids_from_release_body(release_body)
 
         if len(issue_ids) > 0:
             update_youtrack_state = prompt_utils.ask_confirm(
@@ -255,7 +256,7 @@ class Release:
                 try:
                     self._youtrack.comment(
                         issue_id,
-                        f"Deploy in production of {self._project} in countries {countries} done with the release {new_version}",
+                        f"Deploy in production of {self._project} in countries {countries} done with the release {version}",
                     )
                     if update_youtrack_state:
                         self._youtrack.update_state(issue_id, release_state)
